@@ -1,7 +1,7 @@
-// GetDP - Copyright (C) 1997-2018 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/getdp/getdp/issues
+// issues on https://gitlab.onelab.info/getdp/getdp/issues.
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -120,7 +120,7 @@ void Message::Initialize(int argc, char **argv)
   MPI_Init(&argc, &argv);
   MPI_Comm_rank(MPI_COMM_WORLD, &_commRank);
   MPI_Comm_size(MPI_COMM_WORLD, &_commSize);
-  MPI_Errhandler_set(MPI_COMM_WORLD, MPI_ERRORS_RETURN);
+  MPI_Comm_set_errhandler(MPI_COMM_WORLD, MPI_ERRORS_RETURN);
 #endif
 #if defined(HAVE_GSL)
   gsl_set_error_handler(&gslErrorHandler);
@@ -154,8 +154,7 @@ void Message::Initialize(int argc, char **argv)
 void Message::Finalize()
 {
 #if defined(HAVE_PETSC)
-  // if: to avoid a 'PETSC ERROR' message when calling MPI_Finalize()
-  // (not coherent with prior MPI_Init(&argc, &argv)... but do nothing when _commSize == 1)
+  // don't call MPI_*() if _commSize == 1: newer PETSc does like it
   if(_commSize > 1){
     int initialized, finalized;
     MPI_Initialized(&initialized);
@@ -612,7 +611,7 @@ void Message::ProgressMeter(int n, int N, const char *fmt, ...)
 
   if(N <= 0 || percent >= _progressMeterCurrent || n > N - 1){
 
-    char str[1024], str2[1024];
+    char str[1024], str2[4096];
     va_list args;
     va_start(args, fmt);
     vsnprintf(str, sizeof(str), fmt, args);
