@@ -1,10 +1,10 @@
 // GetDP - Copyright (C) 1997-2015 P. Dular, C. Geuzaine
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/getdp/getdp/issues
+// issues on https://gitlab.onelab.info/getdp/getdp/issues.
 
-#ifndef _MACRO_MANAGER_H_
-#define _MACRO_MANAGER_H_
+#ifndef MACRO_MANAGER_H
+#define MACRO_MANAGER_H
 
 #include <string>
 
