@@ -1,10 +1,10 @@
-// GetDP - Copyright (C) 1997-2018 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/getdp/getdp/issues
+// issues on https://gitlab.onelab.info/getdp/getdp/issues.
 
-#ifndef _PRO_PARSER_H_
-#define _PRO_PARSER_H_
+#ifndef PRO_PARSER_H
+#define PRO_PARSER_H
 
 #include <stdlib.h>
 #include <stdio.h>
