@@ -1,7 +1,7 @@
-// GetDP - Copyright (C) 1997-2018 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/getdp/getdp/issues
+// issues on https://gitlab.onelab.info/getdp/getdp/issues.
 
 #include "GetDPConfig.h"
 
@@ -815,6 +815,8 @@ static void _polynomialEVP(struct DofData * DofData_P, int numEigenValues,
 
 #endif
 
+#if defined(PETSC_USE_COMPLEX)
+
 static PetscErrorCode _myNepMonitor(NEP nep, int its, int nconv, PetscScalar *eigr,
                                     PetscScalar *eigi, PetscReal* errest, int nest,
                                     void *mctx)
@@ -1028,6 +1030,8 @@ static void _rationalEVP(struct DofData * DofData_P, int numEigenValues,
 #endif
 }
 
+#endif
+
 void EigenSolve_SLEPC(struct DofData * DofData_P, int numEigenValues,
                       double shift_r, double shift_i, int FilterExpressionIndex,
                       List_T *RationalCoefsNum, List_T *RationalCoefsDen)
