@@ -1,10 +1,10 @@
-// GetDP - Copyright (C) 1997-2017 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <getdp@onelab.info>.
+// issues on https://gitlab.onelab.info/getdp/getdp/issues.
 
-#ifndef _GEODATA_H_
-#define _GEODATA_H_
+#ifndef GEO_DATA_H
+#define GEO_DATA_H
 
 #include "ListUtils.h"
 #include "TreeUtils.h"
@@ -36,6 +36,7 @@ struct GeoData {
 
   double  * H, * P ;
 
+  List_T  * PeriodicNodes;
 } ;
 
 int  Geo_AddGeoData(List_T * GeoData_L,
@@ -53,9 +54,6 @@ void  Geo_ReadFileAdapt(struct GeoData * GeoData_P) ;
 
 void  Geo_SaveMesh(struct GeoData * GeoData_P, List_T * InitialList, char * FileName) ;
 
-int Geo_GetElementType(int Format, int Type);
-int Geo_GetElementTypeInv(int Format, int Type);
-
 int  Geo_GetNbrGeoElements(void) ;
 struct Geo_Element  * Geo_GetGeoElement(int Index_Element) ;
 int Geo_GetGeoElementIndex(struct Geo_Element * GeoElement) ;
