@@ -1,10 +1,10 @@
-// GetDP - Copyright (C) 1997-2018 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/getdp/getdp/issues
+// issues on https://gitlab.onelab.info/getdp/getdp/issues.
 
-#ifndef _GEO_ENTITY_H_
-#define _GEO_ENTITY_H_
+#ifndef GEO_ENTITY_H
+#define GEO_ENTITY_H
 
 /* Incidence Matrices : Den (EdgesXNodes), Dfe (FacetsXEdges) */
 /* Xp stands for 'expanded' (used in discrete operators)      */
@@ -325,7 +325,6 @@ static int  Dfe_Tetrahedron_Xp []
       0,-1, 1, 0, 0,-1,
       0, 0, 0, 1,-1, 1 } ;
 
-
 static int  Dfn_Tetrahedron [] [NBR_MAX_SUBENTITIES_IN_ELEMENT]
   = { { 1, 2, 4, 0}, { 1, 3, 2, 0},
       { 1, 4, 3, 0}, { 2, 3, 4, 0} } ;
@@ -354,12 +353,7 @@ static double  Nodes_Tetrahedron_2 [][3]
   = { {0., 0., 0.}, {1., 0., 0.}, {0., 1., 0.}, {0., 0., 1.},
       {0.5, 0., 0.}, {0.5, 0.5, 0.}, {0., 0.5, 0.},
       {0., 0., 0.5}, {0., 0.5, 0.5}, {0.5, 0., 0.5} } ;
-/*
-static double  Nodes_Tetrahedron_2 [][3]
-  = { {0., 0., 0.}, {1., 0., 0.}, {0., 1., 0.}, {0., 0., 1.},
-      {0.5, 0., 0.}, {0., 0.5, 0.}, {0., 0., 0.5},
-      {0.5, 0.5, 0.}, {0.5, 0., 0.5}, {0., 0.5, 0.5} } ;
-*/
+
 static int  Den_Tetrahedron_2 [] [NBR_MAX_SUBENTITIES_IN_ELEMENT]
   = { { 1, -2, 0}, { 1, -3, 0}, { 1, -4, 0},
       { 2, -3, 0}, { 2, -4, 0}, { 3, -4, 0} } ;
