@@ -1,7 +1,7 @@
-// GetDP - Copyright (C) 1997-2018 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/getdp/getdp/issues
+// issues on https://gitlab.onelab.info/getdp/getdp/issues.
 //
 // Contributor(s):
 //   David Colignon
@@ -393,7 +393,10 @@ void LinAlg_ReadVector(FILE *file, gVector *V)
   PetscInt n;
   _try(VecGetSize(V->V, &n));
   PetscScalar *tmp = (PetscScalar*)Malloc(n*sizeof(PetscScalar));
-  fread(tmp, sizeof(PetscScalar), n, file);
+  if(!fread(tmp, sizeof(PetscScalar), n, file)){
+    Message::Error("Could not read vector");
+    return;
+  }
   for(PetscInt i = 0; i < n; i++){
     _try(VecSetValues(V->V, 1, &i, &tmp[i], INSERT_VALUES));
   }
@@ -931,6 +934,14 @@ void LinAlg_AddVectorProdVectorDouble(gVector *V1, gVector *V2, double d, gVecto
     Message::Error("Wrong arguments in 'LinAlg_AddVectorProdVectorDouble'");
 }
 
+void LinAlg_AddProdVectorDoubleProdVectorDouble(double alpha, gVector *V1,
+        double beta, gVector *V2, gVector *V3)
+{
+  PetscScalar alpha1 = alpha, beta1 = beta;
+  PetscScalar gamma1 = 0.0;
+  _try(VecAXPBYPCZ(V3->V, alpha1, beta1, gamma1, V1->V, V2->V));
+}
+
 void LinAlg_AddMatrixMatrix(gMatrix *M1, gMatrix *M2, gMatrix *M3)
 {
   PetscScalar tmp = 1.0;
