@@ -1,7 +1,7 @@
-// GetDP - Copyright (C) 1997-2018 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/getdp/getdp/issues
+// issues on https://gitlab.onelab.info/getdp/getdp/issues.
 
 #include <sstream>
 #include <vector>
@@ -30,7 +30,7 @@
 int     Flag_PRE = 0, Flag_CAL = 0, Flag_POS = 0, Flag_RESTART = 0;
 int     Flag_XDATA = 0, Flag_BIN = 0, Flag_SPLIT = 0, Flag_GMSH_VERSION = 1;
 int     Flag_NETWORK_CACHE = 0, Flag_CALLED_WITH_ONELAB_SERVER = 0;
-double  Flag_ORDER = -1.;
+double  Flag_ORDER = -1., Flag_MSH_SCALING = 1.;
 char   *Name_Generic = 0, *Name_Path = 0;
 char   *Name_Resolution = 0;
 char   *Name_MshFile = 0, *Name_AdaptFile = 0;
@@ -45,13 +45,14 @@ static void Info(int level, char *arg0)
   case 0 :
     fprintf(stderr,
 	    "GetDP, a General environment for the treatment of Discrete Problems\n"
-	    "Copyright (C) 1997-2018 P. Dular and C. Geuzaine, University of Liege\n"
+	    "Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege\n"
 	    "Usage: %s [file] [options]\n"
 	    "Processing options:\n"
 	    "  -pre 'Resolution'         pre-processing\n"
 	    "  -cal                      processing\n"
 	    "  -pos 'PostOperation(s)'   post-processing\n"
 	    "  -msh file                 read mesh (in msh format) from file\n"
+            "  -msh_scaling value        scale the input mesh by the given value\n"
             "  -gmshread file(s)         read gmsh data (same as GmshRead in resolution)\n"
             "  -gmshtag tag(s)           tag(s) associated to GmshRead data\n"
 	    "  -restart                  resume processing from where it stopped\n"
@@ -355,6 +356,16 @@ static void Get_Options(int argc, char *argv[], int *sargc, char **sargv, char *
 	}
       }
 
+      else if (!strcmp(argv[i]+1, "msh_scaling")) {
+	i++;
+	if (i < argc && argv[i][0] != '-') {
+	  Flag_MSH_SCALING = atof(argv[i]); i++;
+	}
+	else {
+	  Message::Error("Missing scaling value");
+	}
+      }
+
       else if (!strcmp(argv[i]+1, "adapt") ||
 	       !strcmp(argv[i]+1, "adap") ||
 	       !strcmp(argv[i]+1, "ada")) {
