@@ -1,7 +1,7 @@
-// GetDP - Copyright (C) 1997-2017 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <getdp@onelab.info>.
+// issues on https://gitlab.onelab.info/getdp/getdp/issues.
 //
 // Contributed by Bertrand Thierry
 
@@ -21,7 +21,7 @@ extern struct CurrentData Current ;
 #if defined(HAVE_PETSC) && defined(HAVE_GMSH)
 
 #include "petscksp.h"
-#include <gmsh/Gmsh.h>
+#include <gmsh/GmshGlobal.h>
 #include <gmsh/PView.h>
 #include <gmsh/PViewData.h>
 
@@ -814,25 +814,21 @@ static PetscErrorCode PrintMatrix(Mat A, const char* filename, const char* varna
   // in Kernel/LinAlg_PETSC.cpp
 
   std::string tmp(filename);
-  PetscInt m,n, m_max = 600;
+  PetscInt m,n;
 
   _try(PetscObjectSetName((PetscObject)A, varname));
   // ASCII (if the matrix is not too large)
   _try(MatGetSize(A, &m, &n));
-  if(m < m_max){
-    PetscViewer viewer;
-    _try(PetscViewerASCIIOpen(PETSC_COMM_WORLD, filename, &viewer));
-    _try(PetscViewerSetFormat(viewer, PETSC_VIEWER_ASCII_MATLAB));
-    _try(MatView(A, viewer));
+  PetscViewer viewer;
+  _try(PetscViewerASCIIOpen(PETSC_COMM_WORLD, filename, &viewer));
+  _try(PetscViewerSetFormat(viewer, PETSC_VIEWER_ASCII_MATLAB));
+  _try(MatView(A, viewer));
 #if (PETSC_VERSION_RELEASE == 0 || ((PETSC_VERSION_MAJOR == 3) && (PETSC_VERSION_MINOR >= 2)))
-    _try(PetscViewerDestroy(&viewer));
+  _try(PetscViewerDestroy(&viewer));
 #else
-    _try(PetscViewerDestroy(viewer));
+  _try(PetscViewerDestroy(viewer));
 #endif
-  }
-  else{
-    Message::Warning("Matrix is too large, no ASCII Output (m=%d>%d)", m, m_max);
-  }
+
   // BINARY
   // Add the petscfolder/bin/matlab path to your matlab paths and
   // type the following command in matlab, for real arithmetic :
@@ -1243,10 +1239,19 @@ int Operation_BroadcastFields(struct Resolution  *Resolution_P,
                               struct DofData     *DofData_P0,
                               struct GeoData     *GeoData_P0)
 {
+  if(!MyStaticField || !AllStaticField){
+    // we are not in Operation_IterativeLinearSolver: call the new, generic
+    // BroadcastFields operation:
+    return Operation_BroadcastFieldsGeneric(Resolution_P, Operation_P,
+                                            DofData_P0, GeoData_P0);
+  }
+
+  // in the IterativeLinearSolver-specific BroadCastFields operation, the list
+  // of view tags contains the list of views to *not* broadcast
   std::set<int> fieldsToSkip;
-  for(int i = 0; i < List_Nbr(Operation_P->Case.BroadcastFields.FieldsToSkip); i++){
+  for(int i = 0; i < List_Nbr(Operation_P->Case.BroadcastFields.ViewTags); i++){
     double j;
-    List_Read(Operation_P->Case.BroadcastFields.FieldsToSkip, i, &j);
+    List_Read(Operation_P->Case.BroadcastFields.ViewTags, i, &j);
     fieldsToSkip.insert((int) j);
   }
 
@@ -1270,8 +1275,8 @@ int Operation_BroadcastFields(struct Resolution  *Resolution_P,
                               struct DofData     *DofData_P0,
                               struct GeoData     *GeoData_P0)
 {
-  Message::Error("BroadcastFields requires PETSc and Gmsh");
-  return 0;
+  return Operation_BroadcastFieldsGeneric(Resolution_P, Operation_P,
+                                          DofData_P0, GeoData_P0);
 }
 
 #endif
