@@ -1,7 +1,7 @@
-// GetDP - Copyright (C) 1997-2017 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <getdp@onelab.info>.
+// issues on https://gitlab.onelab.info/getdp/getdp/issues.
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -362,7 +362,7 @@ void Operation_Update(struct DefineSystem * DefineSystem_P,
   }
 
   LinAlg_GetVectorSize(&DofData_P->b, &i) ;
-  if(!i) Message::Error("Generated system is of dimension zero");
+  if(!i) Message::Info("Generated system is of dimension zero");
 
   Free_UnusedSolutions(DofData_P);
 }
