@@ -1,7 +1,7 @@
-// GetDP - Copyright (C) 1997-2018 P. Dular and C. Geuzaine, University of Liege
+// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/getdp/getdp/issues
+// issues on https://gitlab.onelab.info/getdp/getdp/issues.
 
 #include <sstream>
 #include <string.h>
@@ -284,7 +284,7 @@ void  Pos_PrintOnElementsOf(struct PostQuantity     *NCPQ_P,
   /* Check if everything is OK for Adaption */
 
   if(PSO_P->Adapt){
-    if(PSO_P->Dimension == _ALL){
+    if(PSO_P->Dimension == DIM_ALL){
       Message::Error("You have to specify a Dimension for the adaptation (2 or 3)");
       return;
     }
@@ -337,7 +337,6 @@ void  Pos_PrintOnElementsOf(struct PostQuantity     *NCPQ_P,
           ) {
 	Fill_PostElement(Element.GeoElement, PostElement_L, iGeo,
 			 Depth, PSO_P->Skin,
-			 PSO_P->EvaluationPoints,
 			 DecomposeInSimplex, 0, PSO_P->Gauss) ;
       }
       Message::ProgressMeter(iGeo + 1, NbrGeo, "Post-processing (Generate)");
@@ -412,7 +411,6 @@ void  Pos_PrintOnElementsOf(struct PostQuantity     *NCPQ_P,
                                             Flag_GMSH_VERSION == 2 || Flag_BIN)) ? 1 : 0;
 	Fill_PostElement(Element.GeoElement, PostElement_L, iGeo,
 			 PSO_P->Depth, PSO_P->Skin,
-			 PSO_P->EvaluationPoints,
 			 DecomposeInSimplex, HighOrder, PSO_P->Gauss) ;
       }
     }
@@ -870,13 +868,13 @@ void  Pos_PrintOnSection(struct PostQuantity     *NCPQ_P,
       Element.Type       = Element.GeoElement->Type ;
       Current.Region = Element.Region = Element.GeoElement->Region ;
 
-      if((PSO_P->Dimension == _ALL &&
+      if((PSO_P->Dimension == DIM_ALL &&
 	  (Element.GeoElement->Type != POINT)) ||
-	 (PSO_P->Dimension == _3D &&
+	 (PSO_P->Dimension == DIM_3D &&
 	  (Element.GeoElement->Type & (TETRAHEDRON|HEXAHEDRON|PRISM|PYRAMID))) ||
-	 (PSO_P->Dimension == _2D &&
+	 (PSO_P->Dimension == DIM_2D &&
 	  (Element.GeoElement->Type & (TRIANGLE|QUADRANGLE))) ||
-	 (PSO_P->Dimension == _1D &&
+	 (PSO_P->Dimension == DIM_1D &&
 	  (Element.GeoElement->Type & LINE))){
 
 	Get_NodesCoordinatesOfElement(&Element) ;
